==> eam-wshub-proxyclient-11.4-4-sources.jar: net/datastream/schemas/mp_entities/kitsessionpart_001/KitSessionPart.java <==

package net.datastream.schemas.mp_entities.kitsessionpart_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_fields.BINID_Type;
import net.datastream.schemas.mp_fields.EQUIPMENTID_Type;
import net.datastream.schemas.mp_fields.KITSESSIONPARTID_Type;
import net.datastream.schemas.mp_fields.LOTID_Type;
import net.datastream.schemas.mp_fields.PARTID_Type;
import org.openapplications.oagis_segments.QUANTITY;


/**
 * <p>Classe Java pour anonymous complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}KITSESSIONPARTID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DBSESSIONID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PARTID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}BINID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}LOTID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ISSUEDQTY"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ASSETID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}SELECT" minOccurs="0"/>
 *       &lt;/sequence>
 *       &lt;attribute name="recordid" type="{http://www.w3.org/2001/XMLSchema}long" />
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "kitsessionpartid",
    "dbsessionid",
    "partid",
    "binid",
    "lotid",
    "issuedqty",
    "assetid",
    "select"
})
@XmlRootElement(name = "KitSessionPart")
public class KitSessionPart {

    @XmlElement(name = "KITSESSIONPARTID", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected KITSESSIONPARTID_Type kitsessionpartid;
    @XmlElement(name = "DBSESSIONID", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected QUANTITY dbsessionid;
    @XmlElement(name = "PARTID", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected PARTID_Type partid;
    @XmlElement(name = "BINID", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected BINID_Type binid;
    @XmlElement(name = "LOTID", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected LOTID_Type lotid;
    @XmlElement(name = "ISSUEDQTY", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected QUANTITY issuedqty;
    @XmlElement(name = "ASSETID", namespace = "http://schemas.datastream.net/MP_fields")
    protected EQUIPMENTID_Type assetid;
    @XmlElement(name = "SELECT", namespace = "http://schemas.datastream.net/MP_fields")
    protected String select;
    @XmlAttribute(name = "recordid")
    protected Long recordid;

    /**
     * Obtient la valeur de la propriété kitsessionpartid.
     * 
     * @return
     *     possible object is
     *     {@link KITSESSIONPARTID_Type }
     *     
     */
    public KITSESSIONPARTID_Type getKITSESSIONPARTID() {
        return kitsessionpartid;
    }

    /**
     * Définit la valeur de la propriété kitsessionpartid.
     * 
     * @param value
     *     allowed object is
     *     {@link KITSESSIONPARTID_Type }
     *     
     */
    public void setKITSESSIONPARTID(KITSESSIONPARTID_Type value) {
        this.kitsessionpartid = value;
    }

    /**
     * Obtient la valeur de la propriété dbsessionid.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getDBSESSIONID() {
        return dbsessionid;
    }

    /**
     * Définit la valeur de la propriété dbsessionid.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setDBSESSIONID(QUANTITY value) {
        this.dbsessionid = value;
    }

    /**
     * Obtient la valeur de la propriété partid.
     * 
     * @return
     *     possible object is
     *     {@link PARTID_Type }
     *     
     */
    public PARTID_Type getPARTID() {
        return partid;
    }

    /**
     * Définit la valeur de la propriété partid.
     * 
     * @param value
     *     allowed object is
     *     {@link PARTID_Type }
     *     
     */
    public void setPARTID(PARTID_Type value) {
        this.partid = value;
    }

    /**
     * Obtient la valeur de la propriété binid.
     * 
     * @return
     *     possible object is
     *     {@link BINID_Type }
     *     
     */
    public BINID_Type getBINID() {
        return binid;
    }

    /**
     * Définit la valeur de la propriété binid.
     * 
     * @param value
     *     allowed object is
     *     {@link BINID_Type }
     *     
     */
    public void setBINID(BINID_Type value) {
        this.binid = value;
    }

    /**
     * Obtient la valeur de la propriété lotid.
     * 
     * @return
     *     possible object is
     *     {@link LOTID_Type }
     *     
     */
    public LOTID_Type getLOTID() {
        return lotid;
    }

    /**
     * Définit la valeur de la propriété lotid.
     * 
     * @param value
     *     allowed object is
     *     {@link LOTID_Type }
     *     
     */
    public void setLOTID(LOTID_Type value) {
        this.lotid = value;
    }

    /**
     * Obtient la valeur de la propriété issuedqty.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getISSUEDQTY() {
        return issuedqty;
    }

    /**
     * Définit la valeur de la propriété issuedqty.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setISSUEDQTY(QUANTITY value) {
        this.issuedqty = value;
    }

    /**
     * Obtient la valeur de la propriété assetid.
     * 
     * @return
     *     possible object is
     *     {@link EQUIPMENTID_Type }
     *     
     */
    public EQUIPMENTID_Type getASSETID() {
        return assetid;
    }

    /**
     * Définit la valeur de la propriété assetid.
     * 
     * @param value
     *     allowed object is
     *     {@link EQUIPMENTID_Type }
     *     
     */
    public void setASSETID(EQUIPMENTID_Type value) {
        this.assetid = value;
    }

    /**
     * Obtient la valeur de la propriété select.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getSELECT() {
        return select;
    }

    /**
     * Définit la valeur de la propriété select.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setSELECT(String value) {
        this.select = value;
    }

    /**
     * Obtient la valeur de la propriété recordid.
     * 
     * @return
     *     possible object is
     *     {@link Long }
     *     
     */
    public Long getRecordid() {
        return recordid;
    }

    /**
     * Définit la valeur de la propriété recordid.
     * 
     * @param value
     *     allowed object is
     *     {@link Long }
     *     
     */
    public void setRecordid(Long value) {
        this.recordid = value;
    }

}

==> eam-wshub-proxyclient-11.7-4-sources.jar: net/datastream/schemas/mp_entities/kitsessionpart_001/KitSessionPart.java <==

package net.datastream.schemas.mp_entities.kitsessionpart_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_fields.BINID_Type;
import net.datastream.schemas.mp_fields.EQUIPMENTID_Type;
import net.datastream.schemas.mp_fields.KITSESSIONPARTID_Type;
import net.datastream.schemas.mp_fields.LOTID_Type;
import net.datastream.schemas.mp_fields.PARTID_Type;
import org.openapplications.oagis_segments.QUANTITY;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}KITSESSIONPARTID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DBSESSIONID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PARTID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}BINID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}LOTID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ISSUEDQTY"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ASSETID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}SELECT" minOccurs="0"/>
 *       &lt;/sequence>
 *       &lt;attribute name="recordid" type="{http://www.w3.org/2001/XMLSchema}long" />
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "kitsessionpartid",
    "dbsessionid",
    "partid",
    "binid",
    "lotid",
    "issuedqty",
    "assetid",
    "select"
})
@XmlRootElement(name = "KitSessionPart")
public class KitSessionPart {

    @XmlElement(name = "KITSESSIONPARTID", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected KITSESSIONPARTID_Type kitsessionpartid;
    @XmlElement(name = "DBSESSIONID", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected QUANTITY dbsessionid;
    @XmlElement(name = "PARTID", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected PARTID_Type partid;
    @XmlElement(name = "BINID", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected BINID_Type binid;
    @XmlElement(name = "LOTID", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected LOTID_Type lotid;
    @XmlElement(name = "ISSUEDQTY", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected QUANTITY issuedqty;
    @XmlElement(name = "ASSETID", namespace = "http://schemas.datastream.net/MP_fields")
    protected EQUIPMENTID_Type assetid;
    @XmlElement(name = "SELECT", namespace = "http://schemas.datastream.net/MP_fields")
    protected String select;
    @XmlAttribute(name = "recordid")
    protected Long recordid;

    /**
     * Gets the value of the kitsessionpartid property.
     * 
     * @return
     *     possible object is
     *     {@link KITSESSIONPARTID_Type }
     *     
     */
    public KITSESSIONPARTID_Type getKITSESSIONPARTID() {
        return kitsessionpartid;
    }

    /**
     * Sets the value of the kitsessionpartid property.
     * 
     * @param value
     *     allowed object is
     *     {@link KITSESSIONPARTID_Type }
     *     
     */
    public void setKITSESSIONPARTID(KITSESSIONPARTID_Type value) {
        this.kitsessionpartid = value;
    }

    /**
     * Gets the value of the dbsessionid property.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getDBSESSIONID() {
        return dbsessionid;
    }

    /**
     * Sets the value of the dbsessionid property.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setDBSESSIONID(QUANTITY value) {
        this.dbsessionid = value;
    }

    /**
     * Gets the value of the partid property.
     * 
     * @return
     *     possible object is
     *     {@link PARTID_Type }
     *     
     */
    public PARTID_Type getPARTID() {
        return partid;
    }

    /**
     * Sets the value of the partid property.
     * 
     * @param value
     *     allowed object is
     *     {@link PARTID_Type }
     *     
     */
    public void setPARTID(PARTID_Type value) {
        this.partid = value;
    }

    /**
     * Gets the value of the binid property.
     * 
     * @return
     *     possible object is
     *     {@link BINID_Type }
     *     
     */
    public BINID_Type getBINID() {
        return binid;
    }

    /**
     * Sets the value of the binid property.
     * 
     * @param value
     *     allowed object is
     *     {@link BINID_Type }
     *     
     */
    public void setBINID(BINID_Type value) {
        this.binid = value;
    }

    /**
     * Gets the value of the lotid property.
     * 
     * @return
     *     possible object is
     *     {@link LOTID_Type }
     *     
     */
    public LOTID_Type getLOTID() {
        return lotid;
    }

    /**
     * Sets the value of the lotid property.
     * 
     * @param value
     *     allowed object is
     *     {@link LOTID_Type }
     *     
     */
    public void setLOTID(LOTID_Type value) {
        this.lotid = value;
    }

    /**
     * Gets the value of the issuedqty property.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getISSUEDQTY() {
        return issuedqty;
    }

    /**
     * Sets the value of the issuedqty property.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setISSUEDQTY(QUANTITY value) {
        this.issuedqty = value;
    }

    /**
     * Gets the value of the assetid property.
     * 
     * @return
     *     possible object is
     *     {@link EQUIPMENTID_Type }
     *     
     */
    public EQUIPMENTID_Type getASSETID() {
        return assetid;
    }

    /**
     * Sets the value of the assetid property.
     * 
     * @param value
     *     allowed object is
     *     {@link EQUIPMENTID_Type }
     *     
     */
    public void setASSETID(EQUIPMENTID_Type value) {
        this.assetid = value;
    }

    /**
     * Gets the value of the select property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getSELECT() {
        return select;
    }

    /**
     * Sets the value of the select property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setSELECT(String value) {
        this.select = value;
    }

    /**
     * Gets the value of the recordid property.
     * 
     * @return
     *     possible object is
     *     {@link Long }
     *     
     */
    public Long getRecordid() {
        return recordid;
    }

    /**
     * Sets the value of the recordid property.
     * 
     * @param value
     *     allowed object is
     *     {@link Long }
     *     
     */
    public void setRecordid(Long value) {
        this.recordid = value;
    }

}
